@@ -1,3 +1,4 @@
+"""Support for loading 3D structures stored in MMTF files."""
 try:
     from mmtf import fetch, parse
 except ImportError:
@@ -14,23 +15,26 @@ def get_from_decoded(decoder):
 
 
 class MMTFParser(object):
-    """Class to get a BioPython structure from a URL or a filename."""
+    """Class to get a Biopython structure from a URL or a filename."""
+
     @staticmethod
     def get_structure_from_url(pdb_id):
         """Get a structure from a URL - given a PDB id.
 
         :param pdb_id: the input PDB id
         :return: the structure
+
         """
         decoder = fetch(pdb_id)
         return get_from_decoded(decoder)
 
     @staticmethod
     def get_structure(file_path):
-        """Get a structrue from a file - given a file path.
+        """Get a structure from a file - given a file path.
 
         :param file_path: the input file path
         :return: the structure
+
         """
         decoder = parse(file_path)
         return get_from_decoded(decoder)
