@@ -89,7 +89,7 @@ class PlateRecord(object):
     >>> 'A01' in plate
     True
 
-    All the wells belonging to a "row" (identified by the first charachter of
+    All the wells belonging to a "row" (identified by the first character of
     the well id) in the plate can be obtained:
 
     >>> for well in plate.get_row('H'):
@@ -133,6 +133,7 @@ class PlateRecord(object):
     """
 
     def __init__(self, plateid, wells=None):
+        """Initialize the class."""
         self.id = plateid
 
         if wells is None:
@@ -155,12 +156,12 @@ class PlateRecord(object):
         self._update()
 
     def _update(self):
-        """Update the rows and columns string identifiers."""
+        """Update the rows and columns string identifiers (PRIVATE)."""
         self._rows = sorted(set(x[0] for x in self._wells))
         self._columns = sorted(set(x[1:] for x in self._wells))
 
     def _is_well(self, obj):
-        """Check if the given object is a WellRecord object
+        """Check if the given object is a WellRecord object (PRIVATE).
 
         Used both for the class constructor and the __setitem__ method
         """
@@ -350,7 +351,7 @@ class PlateRecord(object):
         return False
 
     def __len__(self):
-        """Returns the number of wells in this plate"""
+        """Return the number of wells in this plate."""
         return len(self._wells)
 
     def __eq__(self, other):
@@ -363,12 +364,12 @@ class PlateRecord(object):
         return not self.__eq__(other)
 
     def __add__(self, plate):
-        """Add another PlateRecord object
+        """Add another PlateRecord object.
 
         The wells in both plates must be the same
 
         A new PlateRecord object is returned, having the same id as the
-        left operand
+        left operand.
         """
         if not isinstance(plate, PlateRecord):
             raise TypeError('Expecting a PlateRecord object')
@@ -386,12 +387,12 @@ class PlateRecord(object):
         return newp
 
     def __sub__(self, plate):
-        """Subtract another PlateRecord object
+        """Subtract another PlateRecord object.
 
         The wells in both plates must be the same
 
         A new PlateRecord object is returned, having the same id as the
-        left operand
+        left operand.
         """
         if not isinstance(plate, PlateRecord):
             raise TypeError('Expecting a PlateRecord object')
@@ -409,7 +410,7 @@ class PlateRecord(object):
         return newp
 
     def get_row(self, row):
-        """Get all the wells of a given row
+        """Get all the wells of a given row.
 
         A row is identified with a letter (e.g. 'A')
         """
@@ -426,7 +427,7 @@ class PlateRecord(object):
             yield self._wells[w]
 
     def get_column(self, column):
-        """Get all the wells of a given column
+        """Get all the wells of a given column.
 
         A column is identified with a number (e.g. '6')
         """
@@ -442,7 +443,7 @@ class PlateRecord(object):
             yield self._wells[w]
 
     def subtract_control(self, control='A01', wells=None):
-        """Subtract a 'control' well from the other plates wells
+        """Subtract a 'control' well from the other plates wells.
 
         By default the control is subtracted to all wells, unless
         a list of well ID is provided
@@ -474,7 +475,7 @@ class PlateRecord(object):
         return newp
 
     def __repr__(self):
-        """Returns a (truncated) representation of the plate for debugging."""
+        """Return a (truncated) representation of the plate for debugging."""
         if len(self._wells) > 4:
             # Show the last well and the first three
             return "%s('%s, ..., %s')" % (self.__class__.__name__,
@@ -493,7 +494,7 @@ class PlateRecord(object):
                                ))
 
     def __str__(self):
-        """A human readable summary of the record (string).
+        """Return a human readable summary of the record (string).
 
         The python built in function str works by calling the object's ___str__
         method.  e.g.
@@ -524,11 +525,10 @@ class PlateRecord(object):
 
 
 class WellRecord(object):
-    """WellRecord object stores all the time course signals of a phenotype
-    Microarray well.
+    """WellRecord stores all time course signals of a phenotype Microarray well.
 
-    The single time points and signals can be
-    accessed iterating on the WellRecord or using lists indeces or slices:
+    The single time points and signals can be accessed iterating on the
+    WellRecord or using lists indeces or slices:
 
     >>> from Bio import phenotype
     >>> plate = phenotype.read("plate.csv", "pm-csv")
@@ -582,7 +582,7 @@ class WellRecord(object):
     >>> print(well.slope, well.model)
     (61.853516785566917, 'logistic')
 
-    If not sigmoid function is specified, the first one that is succesfully
+    If not sigmoid function is specified, the first one that is successfully
     fitted is used. The user can also specify a specific function.
 
     >>> well.fit('gompertz')
@@ -594,6 +594,7 @@ class WellRecord(object):
     """
 
     def __init__(self, wellid, plate=None, signals=None):
+        """Initialize the class."""
         if plate is None:
             self.plate = PlateRecord(None)
         else:
@@ -645,7 +646,7 @@ class WellRecord(object):
         self._signals[time] = signal
 
     def __getitem__(self, time):
-        """Returns a subset of signals or a single signal."""
+        """Return a subset of signals or a single signal."""
         if isinstance(time, slice):
             # Fix the missing values in the slice
             if time.start is None:
@@ -688,7 +689,7 @@ class WellRecord(object):
         return not self.__eq__(other)
 
     def __add__(self, well):
-        """Add another WellRecord object
+        """Add another WellRecord object.
 
         A new WellRecord object is returned, having the same id as the
         left operand
@@ -707,7 +708,7 @@ class WellRecord(object):
         return neww
 
     def __sub__(self, well):
-        """Subtract another WellRecord object
+        """Subtract another WellRecord object.
 
         A new WellRecord object is returned, having the same id as the
         left operand
@@ -726,11 +727,11 @@ class WellRecord(object):
         return neww
 
     def __len__(self):
-        """Returns the number of time points sampled"""
+        """Return the number of time points sampled."""
         return len(self._signals)
 
     def __repr__(self):
-        """Returns a (truncated) representation of the signals for debugging."""
+        """Return a (truncated) representation of the signals for debugging."""
         if len(self) > 7:
             # Shows the last time point and the first five
             return "%s('%s, ..., %s')" % (self.__class__.__name__,
@@ -742,9 +743,9 @@ class WellRecord(object):
                                ', '.join([str(x) for x in self.get_raw()]))
 
     def __str__(self):
-        """A human readable summary of the record (string).
+        """Return a human readable summary of the record (string).
 
-        The python built in function str works by calling the object's ___str__
+        The python built-in function str works by calling the object's ___str__
         method.  e.g.
 
         >>> from Bio import phenotype
@@ -774,15 +775,15 @@ class WellRecord(object):
         return "\n".join(lines)
 
     def get_raw(self):
-        """Get a list of time/signal pairs"""
+        """Get a list of time/signal pairs."""
         return [(t, self._signals[t]) for t in sorted(self._signals.keys())]
 
     def get_times(self):
-        """Get a list of the recorded time points"""
+        """Get a list of the recorded time points."""
         return sorted(self._signals.keys())
 
     def get_signals(self):
-        """Get a list of the recorded signals (ordered by collection time)"""
+        """Get a list of the recorded signals (ordered by collection time)."""
         return [self._signals[t] for t in sorted(self._signals.keys())]
 
     def fit(self, function=("gompertz", "logistic", "richards")):
@@ -797,7 +798,7 @@ class WellRecord(object):
          - logistic
          - richards
 
-        The first function that is succesfuly fitted to the signals will
+        The first function that is successfully fitted to the signals will
         be used to extract the curve parameters and update ``.area`` and
         ``.model``. If no function can be fitted an exception is raised.
 
@@ -848,8 +849,7 @@ class WellRecord(object):
 
 
 def JsonIterator(handle):
-    """Generator function to iterate over PM json records (as PlateRecord
-    objects).
+    """Iterate over PM json records as PlateRecord objects.
 
     Arguments:
      - handle - input file
@@ -928,8 +928,7 @@ def JsonIterator(handle):
 
 
 def CsvIterator(handle):
-    """Generator function to iterate over PM csv records (as PlateRecord
-    objects).
+    """Iterate over PM csv records as PlateRecord objects.
 
     Arguments:
      - handle - input file
@@ -1112,6 +1111,7 @@ class JsonWriter(object):
     """Class to write PM Json format files."""
 
     def __init__(self, plates):
+        """Initialize the class."""
         self.plates = plates
 
     def write(self, handle):
